Global Const $HID_USAGE_X = 0x30
Global Const $HID_USAGE_Y = 0x31
Global Const $HID_USAGE_Z = 0x32
Global Const $HID_USAGE_RX = 0x33
Global Const $HID_USAGE_RY = 0x34
Global Const $HID_USAGE_RZ = 0x35
Global Const $HID_USAGE_SL0 = 0x36
Global Const $HID_USAGE_SL1 = 0x37
Global Const $HID_USAGE_WHL = 0x38
Global Const $HID_USAGE_POV = 0x39

Global Enum $VJD_STAT_OWN, $VJD_STAT_FREE, $VJD_STAT_BUSY, $VJD_STAT_MISS, $VJD_STAT_UNKN
Global $hDLLVjoy = 0
Global $stVjoy
; #STRUCTURE# ===================================================================================================================
; Name ..........: $tagVjoy
; Description ...:
; Fields ........: bDevice              - A BYTE value.	 1		// Index of device. 1-based.
;                  wThrottle[3]         - A long value.			LONG wThrottle;LONG	wRudder;LONG wAileron;
;                  wAxisX               - A long value.  3
;                  wAxisY               - A long value.  4
;                  wAxisZ               - A long value.  5
;                  wAxisXRot            - A long value.  6
;                  wAxisYRot            - A long value.  7
;                  wAxisZRot            - A long value.  8
;                  wSlider              - A long value.  9
;                  wDial                - A long value.  10
;                  wWheel[7]            - A long value.			LONG wWheel;LONG wAxisVX;LONG wAxisVY;LONG wAxisVZ;LONG	wAxisVBRX;LONG wAxisVBRY;LONG wAxisVBRZ;
;                  lButtons             - A long value.	 12		// 32 buttons: 0x00000001 means button1 is pressed, 0x80000000 -> button32 is pressed
;                  bHats[4]             - A DWORD value. 13		DWORD bHats;DWORD bHatsEx1;DWORD bHatsEx2;DWORD bHatsEx3;
; Author ........: Thierry Kielbasiewicz						// Lower 4 bits: HAT switch or 16-bit of continuous HAT switch
; Remarks .......:
; Related .......:
; ===============================================================================================================================
;~ Global Const $tagVjoy = "BYTE bDevice;" & _
;~ 		"long wThrottle[3];" & _
;~ 		"long X;" & _
;~ 		"long Y;" & _
;~ 		"long Z;" & _
;~ 		"long XRot;" & _
;~ 		"long YRot;" & _
;~ 		"long ZRot;" & _
;~ 		"long Slider;" & _
;~ 		"long Dial;" & _
;~ 		"long wWheel[7];" & _
;~ 		"long lButtons;" & _
;~ 		"DWORD bHats[4];"
;							1			2		  3,1 to 3,8	4			5			6,1 to 6,4
Global Const $tagVjoy = "BYTE bDevice;long $a[3];long Axis[8];long $b[7];long lButtons;DWORD bHats[4];"
; #FUNCTION# ====================================================================================================================
; Name ..........: _Vjoy_Startup
; Description ...:
; Syntax ........: _Vjoy_Startup()
; Parameters ....:
; Return values .: None
; Author ........: Thierry Kielbasiewicz
; Modified ......:
; Remarks .......: $stVjoy = DllStructCreate($tagVjoy)
; Related .......:
; Link ..........:
; Example .......: No
; ===============================================================================================================================
Func _Vjoy_Startup()
	Local $hr
	$hDLLVjoy = DllOpen("vJoyInterface.dll")
	$hr = DllCall($hDLLVjoy, "BOOL:cdecl", "vJoyEnabled")
	If Not $hr[0] Then _TraitVjoyError($hr, "Vjoy Driver not enabled")
	$hr = DllCall($hDLLVjoy, "int:cdecl", "GetVJDStatus", "uint", 1)
	If $hr[0] = $VJD_STAT_FREE Then
		$hr = DllCall($hDLLVjoy, "BOOL:cdecl", "AcquireVJD", "uint", 1)
		If Not $hr[0] Then _TraitVjoyError($hr, "Vjoy Driver can not be acquired")
	EndIf
	$stVjoy = DllStructCreate($tagVjoy)
	write("Vjoy startup")
EndFunc   ;==>_Vjoy_Startup
; #FUNCTION# ====================================================================================================================
; Name ..........: _Vjoy_Stop
; Description ...:
; Syntax ........: _Vjoy_Stop($iInterface)
; Parameters ....: $iInterface          - An integer value.
; Return values .: None
; Author ........: Thierry Kielbasiewicz
; Modified ......:
; Remarks .......:
; Related .......:
; Link ..........:
; Example .......: No
; ===============================================================================================================================
Func _Vjoy_Stop($iInterface)
	DllCall($hDLLVjoy, "BOOL:cdecl", "ResetButtons", "uint", $iInterface)
	DllCall($hDLLVjoy, "BOOL:cdecl", "ResetPovs", "uint", $iInterface)
	Local $hr
	$hr = DllCall($hDLLVjoy, "int:cdecl", "GetVJDStatus", "uint", $iInterface)
	If $hr[0] = $VJD_STAT_OWN Then
		DllCall($hDLLVjoy, "none:cdecl", "RelinquishVJD", "uint", $iInterface)
		If @error Then MsgBox(0, @error, "relinquish")
	EndIf
	$stVjoy = 0
	DllClose($hDLLVjoy)
	write("Vjoy stopped")
EndFunc   ;==>_Vjoy_Stop
; #FUNCTION# ====================================================================================================================
; Name ..........: _UpdateVjoy
; Description ...:
; Syntax ........: _UpdateVjoy($iInterface)
; Parameters ....: $iInterface          - An integer value.
; Return values .: None
; Author ........: Thierry Kielbasiewicz
; Modified ......:
; Remarks .......:
; Related .......:
; Link ..........:
; Example .......: No
; ===============================================================================================================================
Func _UpdateVjoy($iInterface)
	$hr = DllCall($hDLLVjoy, "BOOL:cdecl", "UpdateVJD", "uint", $iInterface, "ptr", DllStructGetPtr($stVjoy))
	If Not $hr[0] Then _TraitError($hr, "Vjoy Driver can not be updated")
EndFunc   ;==>_UpdateVjoy
; #FUNCTION# ====================================================================================================================
; Name ..........: _TraitVjoyError
; Description ...:
; Syntax ........: _TraitVjoyError(Byref $hr, $sMSG)
; Parameters ....: $hr                  - [in/out] A handle value.
;                  $sMSG                - A string value.
; Return values .: None
; Author ........: Thierry Kielbasiewicz
; Modified ......:
; Remarks .......:
; Related .......:
; Link ..........:
; Example .......: No
; ===============================================================================================================================
Func _TraitVjoyError(ByRef $hr, $sMSG)
	MsgBox(0, "Fatal Error:" & $hr[0], $sMSG)
	_Vjoy_Stop(1)
EndFunc   ;==>_TraitVjoyError