#include <String.au3>
;#include <WinApi.au3>


;~ Global $c_dfDIKeyboard = _Init_c_dfDIKeyboard()
;~ Global $c_dfDIMouse = _Init_c_dfDIMouse()
;~ Global $c_dfDIJoystick = _Init_c_dfDIJoystick()

; #FUNCTION# ===========================================================================================================
; Name ..........: __DEFINE_GUID
; Description ...:
; Syntax ........: __DEFINE_GUID($sGuid, $d1, $d2, $d3, $d4, $d5, $d6, $d7, $d8, $d9, $d10, $d11)
; Parameters ....: $sGuid               - A string value.
;                  $d1                  - An integer value, part of GUID.
;                  $d2                  - An integer value, part of GUID.
;                  $d3                  - An integer value, part of GUID.
;                  $d4                  - An integer value, part of GUID.
;                  $d5                  - An integer value, part of GUID.
;                  $d6                  - An integer value, part of GUID.
;                  $d7                  - An integer value, part of GUID.
;                  $d8                  - An integer value, part of GUID.
;                  $d9                  - An integer value, part of GUID.
;                  $d10                 - An integer value, part of GUID.
;                  $d11                 - An integer value, part of GUID.
; Return values .: None
; Author ........: Thierry Kielbasiewicz
; Modified ......:
; Remarks .......: Create Global var: tGUID_XAxis, tGUID_YAxis etc    (Assign is used)
; Related .......:
; Link ..........:
; Example .......: No
; ===============================================================================================================================
Func __DEFINE_GUID($sGuid, $d1, $d2, $d3, $d4, $d5, $d6, $d7, $d8, $d9, $d10, $d11)
	Local $tGuid = "t" & $sGuid
	If IsDeclared($tGuid) Then Return
	Local $var = "{" & Hex($d1, 8) & "-" & Hex($d2, 4) & "-" & Hex($d3, 4) & "-" & Hex($d4, 2) & Hex($d5, 2) & "-" & _
			Hex($d6, 2) & Hex($d7, 2) & Hex($d8, 2) & Hex($d9, 2) & Hex($d10, 2) & Hex($d11, 2) & "}"
	;	Assign($sGuid, $var, 2) ; uncomment if Guid string is needed
	Assign($tGuid, _WinAPI_GUIDFromString($var), 2)
EndFunc   ;==>__DEFINE_GUID

Func _ZeroMemory($pMemory, $iLength)
	DllCall('Kernel32.dll', 'none', 'RtlZeroMemory', 'ptr', $pMemory, 'ulong_ptr', $iLength)
	If @error Then
		Return SetError(1, 0, 0)
	EndIf
	Return 1
EndFunc   ;==>_WinAPI

; #FUNCTION# ====================================================================================================================
; Name...........: _WinAPI_MoveMemory
; Description....: Moves a block of memory from one location to another.
; Syntax.........: _WinAPI_MoveMemory ( $pDestination, $pSource, $iLength )
; Parameters.....: $pDestination - A pointer to the starting address of the move destination.
;                  $pSource      - A pointer to the starting address of the block of memory to be moved.
;                  $iLength      - The size of the block of memory to move, in bytes.
; Return values..: Success       - 1.
;                  Failure       - 0 and sets the @error flag to non-zero.
; Author.........: Yashied
; Modified.......:
; Remarks........: The source and destination blocks may overlap.
; Related........:
; Link...........: @@MsdnLink@@ RtlMoveMemory
; Example........: Yes
; ===============================================================================================================================
Func _MoveMemory($pDestination, $pSource, $iLength)
	DllCall('Kernel32.dll', 'none', 'RtlMoveMemory', 'ptr', $pDestination, 'ptr', $pSource, 'ulong_ptr', $iLength)
	If @error Then
		Return SetError(1, 0, 0)
	EndIf
	Return 1
EndFunc   ;==>_WinAPI_MoveMemory
Func _FillMemory($pMemory, $iLength, $iValue = 0)
	DllCall('kernel32.dll', 'none', 'RtlFillMemory', 'ptr', $pMemory, 'ulong_ptr', $iLength, 'byte', $iValue)
	If @error Then
		Return SetError(1, 0, 0)
	EndIf
	Return 1
EndFunc   ;==>_WinAPI_FillMemory
; #FUNCTION# ====================================================================================================================
; Name ..........: _FAILED
; Description ...:
; Syntax ........: _FAILED($Status)
; Parameters ....: $Status              - A long value.
; Return values .: None
; Author ........: Thierry Kielbasiewicz
; Modified ......:
; Remarks .......:
; Related .......:
; Link ..........:
; Example .......: No
; ===============================================================================================================================
Func _FAILED($Status)
	Return ($Status<0)
EndFunc
; #FUNCTION# ====================================================================================================================
; Name ..........: _TraitError
; Description ...:
; Syntax ........: _TraitError($hr, $act)
; Parameters ....: $hr                  - A handle value.
;                  $act                 - An array of unknowns.
; Return values .: None
; Author ........: Thierry Kielbasiewicz
; Modified ......:
; Remarks .......:
; Related .......:
; Link ..........:
; Example .......: No
; ===============================================================================================================================
Func _TraitError($hr, $act)
	Local $msg
	Switch($hr)
		Case 0x80020006
			$msg = "Unknown name (DISP_E_UNKNOWNNAME)"
		Case 0x80004003
			$msg = "Invalid pointer (E_POINTER)"
		Case 0x80070006
			$msg = "The handle is invalid (E_HANDLE)"
		Case 0x8007000C
				$msg = "Access code is invalid (E_ACCESSDENIED)"
		Case 0x80070057
			$msg = "Invalid argument (E_INVALIDARG)"
		Case Else
			$msg = "Error Uknown"
	EndSwitch

	MsgBox(0, "Error " & $act, "0x" & hex($hr,8) & "-> " & $msg)
;	_Quit()
EndFunc

